#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for running the tests.

@author: mark
"""

import logging
import unittest
from solventmapcreator.test.iotest.solvationenergyreadertest import SolvationEnergyReaderTestCase
from solventmapcreator.test.iotest.polynomialdatawritertest import PolynomialDataWriterTestCase
from solventmapcreator.test.iotest.polynomialdatareadertest import PolynomialDataReaderTestCase
from solventmapcreator.test.solvationcalculationtest.solvationcalculatortest import SolvationCalculatorTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialdataanalysistest import PolynomialDataAnalysisTestCase
from solventmapcreator.test.polynomialanalysistest.polynomialcomparisontest import PolynomialComparisonTestCase

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

IO_TEST_CASES = [SolvationEnergyReaderTestCase, PolynomialDataWriterTestCase,
                 PolynomialDataReaderTestCase]

SOLVATION_CALCULATION_TEST_CASES = [SolvationCalculatorTestCase]

POLYNOMIAL_ANALYSIS_TEST_CASES = [PolynomialDataAnalysisTestCase,
                                  PolynomialComparisonTestCase]

def test_suite():
    """Function creates a test suite and then loads all the tests from the
    different test cases.
    """
    LOGGER.info("setting up loader and test suite")
    loader = unittest.TestLoader()
    suite = unittest.TestSuite()
    for test_case in IO_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    for test_case in SOLVATION_CALCULATION_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    for test_case in POLYNOMIAL_ANALYSIS_TEST_CASES:
        LOGGER.debug("Adding %s", test_case)
        suite.addTests(loader.loadTestsFromTestCase(test_case))
    return suite

if __name__ == '__main__':
    LOGGER.info("calling test suite method")
    SUITE = test_suite()
    LOGGER.info("running test suite")
    unittest.TextTestRunner(verbosity=2).run(SUITE)
